searchData={"items":[{"type":"module","title":"RegexFormatter","doc":"RegexFormatter\n--------------\nDon't fear the regex. Malleable 'mix format' via powerful code-search/replace.\n\nUsage\n-----\nConfigure and run Regex Formatter in three steps:\n\n1. Add `RegexFormatter` to `plugins` list in `.formatter.exs`.\n2. Add `regex_formatter` config to `.formatter.exs` following examples below.\n3. Run `mix format` — Regex Formatter rules will run after normal format operations.\n\n```elixir\n[                                        #  ┌── [1] Add RegexFormatter to plugins.\n  ...                                    #  │\n  plugins: [Phoenix.LiveView.HTMLFormatter, RegexFormatter],\n  regex_formatter: [  #  <───── [2] Add configuration for RegexFormatter.\n    [\n      extensions: [\".ex\", \".exs\"],  #  <─── [3] Configure file types to replace on.\n      replacements: [\n        {\n          ~r/~u[\"]\\s+/s,  #  <───── [4] Define search pattern.\n          \"~u\\\"\"          #  <───── [5] Define replacement pattern.\n        },\n        {\n          ~r/(~u[\"][^\"]+[^\"\\s])  +([^\"\\s])/s,\n          ~S'\\1 \\2',   #  <─────── [6] Replace with matched groups.\n          repeat: 100,\n          # Repeat substitutions to correctly handle overlapping matches.\n          # (repeated substitution will stop as soon as text stops changing)\n        }\n      ]\n    ],\n    [\n      sigils: [:SQL],  #  <───────── [7] Try substitution within sigils.\n      replacements: [\n        {\n          ~r/(~u[\"][^\"]+[^\"\\s])\\s+\"/s,\n          ~S'\\1\"'\n        }\n      ]\n    ],\n    [                               #  ┌──── [8] Try handy substitution presets.\n      extensions: [\".ex\", \".exs\"],  #  │\n      preset_trim_sigil_whitespace: [:u],\n      preset_collapse_sigil_whitespace: [:u, :SQL],\n      preset_do_on_separate_line_after_multiline_keyword_args: true\n    ]\n  ]\n]\n```","ref":"RegexFormatter.html"},{"type":"extras","title":"Regex Formatter","doc":"# Regex Formatter\n\nDon't fear the regex. Malleable `mix format` via powerful code-search/replace.","ref":"readme.html"},{"type":"extras","title":"Installation - Regex Formatter","doc":"Add `regex_formatter` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:regex_formatter, \"~> 0.1\"}\n  ]\nend\n```\nthen\n```\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Regex Formatter","doc":"Configure and run Regex Formatter in three steps:\n\n1. Add `RegexFormatter` to `plugins` list in `.formatter.exs`.\n2. Add `regex_formatter` config to `.formatter.exs` following examples below.\n3. Run `mix format` — Regex Formatter rules will run after normal format operations.\n\n```elixir\n[                                        #  ┌── [1] Add RegexFormatter to plugins.\n  ...                                    #  │\n  plugins: [Phoenix.LiveView.HTMLFormatter, RegexFormatter],\n  regex_formatter: [  #  <───────────────────── [2] Add configuration for RegexFormatter.\n    [\n      extensions: [\".ex\", \".exs\"],  #  <─────── [3] Configure file types to replace on.\n      replacements: [\n        {\n          ~r/~u[\"]\\s+/s,  #  <───────────────── [4] Define search pattern.\n          \"~u\\\"\"          #  <───────────────── [5] Define replacement pattern.\n        },\n        {\n          ~r/(~u[\"][^\"]+[^\"\\s])  +([^\"\\s])/s,\n          ~S'\\1 \\2',   #  <──────────────────── [6] Replace with matched groups.\n          repeat: 100,\n          # Repeat substitutions to correctly handle overlapping matches.\n          # (repeated substitution will stop as soon as text stops changing)\n        },\n      ]\n    ],\n    [\n      sigils: [:sql],  #  <──────────────────── [7] Try substitution within sigils.\n      replacements: [\n        {\n          ~r/(~u[\"][^\"]+[^\"\\s])\\s+\"/s,\n          ~S'\\1\"'\n        },\n      ]\n    ],\n    [                               #  ┌─────── [8] Try handy substitution presets.\n      extensions: [\".ex\", \".exs\"],  #  │\n      preset_trim_sigil_whitespace: [:u],\n      preset_collapse_sigil_whitespace: [:u, :SQL],\n      preset_do_on_separate_line_after_multiline_keyword_args: true\n    ]\n  ]\n]\n```","ref":"readme.html#usage"},{"type":"extras","title":"Presets - Regex Formatter","doc":"Included preset substitutions can give an idea of what this plugin may be useful for:\n\n- `preset_trim_sigil_whitespace`\n    - When provided a list of sigils, eg. `[:u, :SQL]`, this preset will trim leading\n      and trailing whitespace from around these sigil values in code. For instance,\n      `~u\" hello  world  \"` will become `~u\"hello  world\"`. This also works with\n      multiline sigil values (without disrupting newlines).\n    - Add `preset_trim_sigil_whitespace: [:u, :SQL]` to `regex_formatter` config to\n      invoke this preset (see full example above).\n\n- `preset_collapse_sigil_whitespace`\n    - When provided a list of sigils, eg. `[:u, :SQL]`, this preset will \"collapse\"\n      extraneous whitespace within these sigil values in code. For instance,\n      `~u\" hello  world  \"` will become `~u\" hello world  \"`. This also works with\n      multiline sigil values (without disrupting newlines).\n    - Add `preset_collapse_sigil_whitespace: [:u, :SQL]` to `regex_formatter` config to\n      invoke this preset (see full example above).\n\n- `preset_do_on_separate_line_after_multiline_keyword_args`\n    - By default, when a function call has keyword args split across multiple lines,\n      `mix format` places `do` on the same line as the last keyword arg. Depending on\n      exact indentation, this can lead to some difficult-to-read code, as it's not\n      always clear at a glance (based on indentation) which lines constitute keyword\n      args vs. expressions within the `do` scope.\n    - This readability problem is especially pronounced when using the excellent\n      [Temple](https://github.com/mhanberg/temple) system to compose HTML templates.\n    - This preset solves the problem by moving `do` onto its own line in these cases,\n      maintaining correct indentation of keyword args and `do` in the process.\n    - Add `preset_do_on_separate_line_after_multiline_keyword_args: true` to\n      `regex_formatter` config to invoke this preset (see full example above).\n\nTogether, `preset_trim_sigil_whitespace` and `preset_collapse_sigil_whitespace` work\nwell with the `~u`&nbsp;[unique-words sigil](https://hexdocs.pm/unique_words_sigil),\nwell-suited for HTML classes where surrounding/repeated spaces are irrelevant \n(and class names should be unique).","ref":"readme.html#presets"},{"type":"extras","title":"Prior Art - Regex Formatter","doc":"Inspired by the incredibly cool https://github.com/frerich/filter_formatter, which\nalso helped provide excellent initial guidance for setting up a `mix format` plugin.","ref":"readme.html#prior-art"},{"type":"extras","title":"License - Regex Formatter","doc":"MIT","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.1"}}